unit Unit1; 

{$mode delphi}

interface

uses
  crt, Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, ExtCtrls,
  StdCtrls, ComCtrls, uLibVLC;

type

  { TForm1 }

  TForm1 = class(TForm)
    btn_OpenFile: TButton;
    btn_Play: TButton;
    btn_Stop: TButton;
    btn_Pause: TButton;
    dlg_Video: TOpenDialog;
    pan_Video: TPanel;
    tm_refreshtrack: TTimer;
    track: TTrackBar;
    procedure btn_OpenFileClick(Sender: TObject);
    procedure btn_PauseClick(Sender: TObject);
    procedure btn_PlayClick(Sender: TObject);
    procedure btn_StopClick(Sender: TObject);
    procedure FormCloseQuery(Sender: TObject; var CanClose: boolean);
    procedure FormCreate(Sender: TObject);
    procedure pan_VideoDblClick(Sender: TObject);
    procedure tm_refreshtrackTimer(Sender: TObject);
    procedure trackChange(Sender: TObject);
  private
    FLib : ILibVLC;
    FLibInstance : Plibvlc_instance_t;
    FPlayer : Plibvlc_media_player_t;
    FMedia : Plibvlc_media_t;
    procedure CheckVLCException;
  public
    { public declarations }
  end; 

var
  Form1: TForm1; 

implementation

{$R *.lfm}

{ TForm1 }

procedure TForm1.FormCloseQuery(Sender: TObject; var CanClose: Boolean);
begin
if Flib.libvlc_media_player_is_playing(FPlayer) <> 0 then
   Flib.libvlc_media_player_stop(FPlayer);

if Assigned(FMedia) then
   Flib.libvlc_media_release(FMedia);

Flib.libvlc_media_player_release(FPlayer);
Flib.libvlc_release(FLibInstance);
Flib.libvlc_free(FLib);
end;

procedure TForm1.FormCreate(Sender: TObject);
var
  params : array[0..1] of PAnsiChar;
begin
  params[0] := PAnsiChar('--plugin-path=C:\Programmierung\LibVLC\examples\bbplayer\plugins\');
  params[1] := PAnsiChar('--ignore-config');

  FLib := LoadLibVLC();
  CheckVLCException;

  FLibInstance := Flib.libvlc_new(Length(params), @params[0]);
  CheckVLCException;

  FPlayer := Flib.libvlc_media_player_new(FlibInstance);
  CheckVLCException;

  Flib.libvlc_media_player_set_hwnd(FPlayer, Pointer(pan_Video.Handle));
  CheckVLCException;
end;

procedure TForm1.pan_VideoDblClick(Sender: TObject);
begin
  if pan_Video.Height = 249 then pan_Video.Height := 640;
  if pan_Video.Width =699 then pan_Video.Width := 480;
end;

procedure TForm1.tm_refreshtrackTimer(Sender: TObject);
begin
  if Flib.libvlc_media_player_is_playing(FPlayer) <> 0 then
     begin
       if track.Max = 1 then
          begin
            if Flib.libvlc_media_get_state(Fmedia) <> libvlc_NothingSpecial then
               track.Max := Round(Flib.libvlc_media_player_get_length(FPlayer) / 1000)
          end
          else
          track.Position := Round(Flib.libvlc_media_player_get_time(FPlayer) / 1000);
          end;
end;

procedure TForm1.trackChange(Sender: TObject);
begin
  if Flib.libvlc_media_player_is_playing(FPlayer) <> 0 then
     begin
       FLib.libvlc_media_player_set_time(FPlayer, track.Position * 1000)
     end;
end;

procedure TForm1.CheckVLCException;
var
  msg : PAnsiChar;
begin
  msg := FLib.libvlc_errmsg;

  if Assigned(msg) then
  begin
    try
      raise Exception.Create(msg);
      writeln(msg);
    finally
      FLib.libvlc_clearerr;
    end;
  end;
end;

procedure TForm1.btn_OpenFileClick(Sender: TObject);
begin
if FLib.libvlc_media_player_is_playing(FPlayer) <> 0 then
Flib.libvlc_media_player_stop(FPlayer);

if dlg_Video.Execute then
begin
  if Assigned(FMedia) then
     Flib.libvlc_media_release(FMedia);
  FMedia := nil;
  track.Max := 1;

  FMedia := Flib.libvlc_media_new_location(FLibInstance, PAnsiChar(AnsiString(dlg_Video.FileName)));
  CheckVLCException;

  Flib.libvlc_media_player_set_media(FPlayer, FMedia);
  CheckVLCException;

  btn_Play.Click;
end;
end;

procedure TForm1.btn_PauseClick(Sender: TObject);
begin
Flib.libvlc_media_player_pause(FPlayer);
CheckVLCException;
end;

procedure TForm1.btn_PlayClick(Sender: TObject);
begin
Flib.libvlc_media_player_play(FPlayer);
CheckVLCException;
end;

procedure TForm1.btn_StopClick(Sender: TObject);
begin
Flib.libvlc_media_player_stop(FPlayer);
CheckVLCException;

end;

end.

